@@ -3,7 +3,7 @@
 '''
 A library to access Tryton's models like a client.
 '''
-__version__ = "2.8.1"
+__version__ = "2.8.2"
 __all__ = ['Model', 'Wizard']
 import sys
 try:
@@ -793,7 +793,7 @@ class Model(object):
             for record in to_remove:
                 # remove without signal
                 list.remove(getattr(self, field), record)
-            if value and value.get('add') or value.get('update'):
+            if value and (value.get('add') or value.get('update')):
                 for vals in value.get('add', []):
                     relation = Model.get(self._fields[field]['relation'],
                             self._config)
